@@ -22,12 +22,13 @@ class ExternalStateAdapter(metaclass=ABCMeta):
     def save_state(self, state: list[InstanceState]):
         if(self.compress):
             for cur_state in state:
-                cur_state.state["settings_log"] = statecompression.compress_settings(cur_state.state["settings_log"])
-                cur_state.state["results_log"] = statecompression.compress_results(cur_state.state["results_log"])
+                if(cur_state is not None and cur_state.state is not None):
+                    cur_state.state["settings_log"] = statecompression.compress_settings(cur_state.state["settings_log"])
+                    cur_state.state["results_log"] = statecompression.compress_results(cur_state.state["results_log"])
         return self._save_state(state)
     
     def save_instance(self, state: InstanceState):
-        if(self.compress):
+        if(self.compress and state is not None and state.state is not None):
                 state.state["settings_log"] = statecompression.compress_settings(state.state["settings_log"])
                 state.state["results_log"] = statecompression.compress_results(state.state["results_log"])
         return self._save_instance(state)
@@ -36,13 +37,14 @@ class ExternalStateAdapter(metaclass=ABCMeta):
         state = self._load_state()
         if(self.compress):
             for cur_state in state:
-                cur_state.state["settings_log"] = statecompression.decompress_settings(cur_state.state["settings_log"])
-                cur_state.state["results_log"] = statecompression.decompress_results(cur_state.state["results_log"])
+                if(cur_state is not None and cur_state.state is not None):
+                    cur_state.state["settings_log"] = statecompression.decompress_settings(cur_state.state["settings_log"])
+                    cur_state.state["results_log"] = statecompression.decompress_results(cur_state.state["results_log"])
         return state
     
     def load_instance(self, instance_uuid: str) -> InstanceState:
         state = self._load_instance(instance_uuid)
-        if(self.compress):
+        if(self.compress and state is not None and state.state is not None):
             state.state["settings_log"] = statecompression.decompress_settings(state.state["settings_log"])
             state.state["results_log"] = statecompression.decompress_results(state.state["results_log"])
         return state
